@@ -452,6 +452,7 @@ def acquire_data(
     Use python nds2 client to get LIGO data.
 
     Inputs:
+    -------
     channels            = array of strs. Valid LIGO channels from which to fetch data
     gps_start           = int. Valid GPS time at which to start acquiring data
     gps_stop            = int. Valid GPS time at which to stop acquiring data
@@ -465,11 +466,13 @@ def acquire_data(
     return_nds2_buffers = bool.  If true, will return the native nds2 buffers and not the usual data dictionary.  Default is False.
 
     Output:
-    Returns the channel buffers native to nds2.
+    -------
+    data_dict: dictionary
+        python dictionary with the channel names as keys and the channel info and data as a value
 
     Valid Host Sever:Port Number combos:
-    h1nds1:8088 # only good on LHO CDS computers
-    h1nds0:8088
+    h1daqnds1:8088 # only good on LHO CDS computers
+    h1daqnds0:8088
     nds.ligo-wa.caltech.edu:31200
     nds.ligo-la.caltech.edu:31200
     nds.ligo.caltech.edu:31200
@@ -905,8 +908,10 @@ def calibrate_dict(data_dict, recalculate=False):
 
 
 def calc_psds(data_dict, averages, bandwidth, overlap, averaging="mean"):
-    """Take PSDs of all channels in data_dict.
-    Returns them in the data_dict provided."""
+    """
+    Take PSDs of all channels in data_dict.
+    Returns them in the data_dict provided.
+    """
     channels = data_dict.keys()
     for chan in channels:
         data = data_dict[chan]["data"]
@@ -942,8 +947,10 @@ def calc_psds(data_dict, averages, bandwidth, overlap, averaging="mean"):
 
 
 def calc_tfs(data_dict):
-    """Takes TFs and coherences of all channels in the data_dict with each other.
-    Returns them in the data_dict provided."""
+    """
+    Takes TFs and coherences of all channels in the data_dict with each other.
+    Returns them in the data_dict provided.
+    """
     channels = np.array(list(data_dict.keys()))
     if "CSD" not in data_dict[channels[0]][channels[1]]:
         print("You must run calc_csds() first!")
@@ -984,16 +991,20 @@ def calc_tfs(data_dict):
             # return a power coherence, but use asds to avoid really small numbers
             coh = (np.abs(csd) / (asd1 * asd2)) ** 2
 
+            # Store TF as chanB/chanA
             data_dict[chan][chan2]["TF"] = tf
             data_dict[chan][chan2]["coh"] = coh
+
     return data_dict
 
 
-def calc_csds(data_dict, averages, bandwidth, overlap, averaging="mean", makeTFs=True):
-    """Takes CSDs of all channels with each other.
+def calc_csds(data_dict, averages, bandwidth, overlap, averaging="mean", make_tfs=True):
+    """
+    Takes CSDs of all channels with each other.
     If PSDs not taken, takes them automatically.
-    If makeTFs=True, creates the TFs of all channels with one another.
-    Returns everything in the data_dict provided."""
+    If make_tfs=True, creates the TFs of all channels with one another.
+    Returns everything in the data_dict provided.
+    """
     channels = np.array(list(data_dict.keys()))
     # Check if PSDs exist, if not make them.
     if "PSD" not in data_dict[channels[0]].keys():
@@ -1086,8 +1097,9 @@ def calc_csds(data_dict, averages, bandwidth, overlap, averaging="mean", makeTFs
             data_dict[chan][chan2]["ff"] = ff
             data_dict[chan][chan2]["CSD"] = Cxy
 
-    if makeTFs:
+    if make_tfs:
         data_dict = calc_tfs(data_dict)
+
     return data_dict
 
 
@@ -1203,7 +1215,7 @@ def get_csds(
     allow_data_on_tape="False",
     gap_handler="STATIC_HANDLER_NAN",
     is_minute_trend=False,
-    makeTFs=True,
+    make_tfs=True,
     verbose=True,
 ):
     """
@@ -1234,7 +1246,7 @@ def get_csds(
                          Usual nds2 default is 'ABORT_HANDLER', which kills your request if there's any unavailable data.
                          More info at https://www.lsc-group.phys.uwm.edu/daswg/projects/nds-client/doc/manual/ch04s02.html.
     is_minute_trend    = bool.  If true, will adjust gps_times to align with minute trend boundaries.  Default is False.
-    makeTFs            = bool.  If true, will calculate transfer functions and power coherence from all calculated CSDs.  Default is True.
+    make_tfs           = bool.  If true, will calculate transfer functions and power coherence from all calculated CSDs.  Default is True.
     verbose            = bool. Default true.  If set will print to terminal all input arguments.
 
     Output:
@@ -1276,7 +1288,7 @@ def get_csds(
         print("allow_data_on_tape = {}".format(allow_data_on_tape))
         print("gap_handler = {}".format(gap_handler))
         print("is_minute_trend = {}".format(is_minute_trend))
-        print("makeTFs = {}".format(makeTFs))
+        print("make_tfs = {}".format(make_tfs))
         print("verbose = {}".format(verbose))
 
     data_dict = acquire_data(
@@ -1290,7 +1302,7 @@ def get_csds(
         is_minute_trend=is_minute_trend,
     )
     data_dict = calc_csds(
-        data_dict, averages, binwidth, overlap, averaging=averaging, makeTFs=makeTFs
+        data_dict, averages, binwidth, overlap, averaging=averaging, make_tfs=make_tfs
     )
     return data_dict
 
@@ -1932,11 +1944,13 @@ def linear_log_psd(log_ff, linear_ff, linear_psd):
     much resolution, i.e. the FFT binwidth > log_ff[1] - log_ff[0].
 
     Inputs:
+    -------
     linear_ff  = linear frequency vector. Will be used for low frequency points.
     log_ff     = log frequency vector.  Will be used for high frequency points.
     linear_psd = linear power spectral density. Should be the same length as linear_ff, usual output of scipy.signal.welch().
 
     Outputs:
+    --------
     fff = stitched frequency vector of linear and log points
     linlog_psd = stitched PSD of linear and log points
     """
@@ -1948,9 +1962,8 @@ def linear_log_psd(log_ff, linear_ff, linear_psd):
     cutoff = log_ff[log_index]  # cutoff frequency
     high_fff = log_ff[log_index + 1 :]
 
-    linear_index = np.argwhere(cutoff < linear_ff)[0][
-        0
-    ]  # find where the cutoff frequency is first less than the linear frequency vector
+    # find where the cutoff frequency is first less than the linear frequency vector
+    linear_index = np.argwhere(cutoff < linear_ff)[0][0]
     low_fff = linear_ff[:linear_index]
     low_psd = linear_psd[:linear_index]
 
@@ -1962,3 +1975,297 @@ def linear_log_psd(log_ff, linear_ff, linear_psd):
     linlog_psd = np.concatenate((low_psd, high_psd))
 
     return fff, linlog_psd
+
+
+### Conditioned spectra calculations
+def calculate_coherence(psd_a, psd_b, csd_ab):
+    """Calculates the power coherence gamma^2(f) between two signals a, b.
+
+    Inputs:
+    -------
+    psd_a: array
+        power spectral density of input signal of interest a <a, a>
+    psd_b: array
+        power spectral density of output signal of interest b <b, b>
+    csd_ab: array
+        cross spectral density between signals a and b <a, b>
+
+    Output:
+    -------
+    coh: array
+        power coherence gamma^2 between a and b, |<a,b>|^2 / (<a,a> * <b,b>)
+    """
+    coh = ( np.abs(csd_ab) / (np.sqrt(psd_a) * np.sqrt(psd_b)) )**2
+    return coh
+
+
+def calculate_conditioned_psd(psd, coh):
+    """Calculates the conditioned power spectral density of the signal producing psd,
+    while removing the influence of another signal coherent with the psd signal.
+
+    Inputs:
+    -------
+    psd: array
+        power spectral density we want to remove another signal from
+    coh: array
+        power coherence between the psd signal and the signal we want to remove
+
+    Outputs:
+    --------
+    conditioned_psd: array
+        power spectral density of the psd signal without the (linear) influence of the coherent signal
+    """
+    conditioned_psd = psd * (1 - coh)
+    return conditioned_psd
+
+
+def calculate_conditioned_csd(csd_ab, csd_ae, csd_be, psd_e):
+    """Calculates the conditioned cross spectral density between two signals of interest a and b,
+    while removing the influence of another signal, e, coherent with both signals.
+
+    Inputs:
+    -------
+    csd_ab: array
+        cross spectral density between signals a and b <a, b>
+    csd_ae: array
+        cross spectral density between signals a and e <a, e>
+    csd_be: array
+        cross spectral density between signals b and e <b, e>
+    psd_e: array
+        power spectral density of signal to be removed e <e, e>
+
+    Outputs:
+    --------
+    conditioned_csd_ab: array
+        cross spectral density between signals a and b <a, b> without the influence of the signal e
+    """
+    conditioned_csd_ab = csd_ab - csd_ae * np.conj(csd_be) / psd_e
+    return conditioned_csd_ab
+
+
+def calculate_conditioned_tf(csd_ab, csd_ae, csd_be, psd_e, psd_a):
+    """Calculates the conditioned transfer function b/a between two signals of interest a and b,
+    while removing the influence of another signal, e, coherent with both signals.
+
+    Inputs:
+    -------
+    csd_ab: array
+        cross spectral density between signals a and b <a, b>
+    csd_ae: array
+        cross spectral density between signals a and e <a, e>
+    csd_be: array
+        cross spectral density between signals b and e <b, e>
+    psd_e: array
+        power spectral density of signal to be removed e <e, e>
+    psd_a: array
+        power spectral density of input signal of interest a <a, a>
+
+    Outputs:
+    --------
+    conditioned_tf: array
+        transfer function between signals a and b <a, b> without the influence of the signal e
+    """
+    coh_ae = calculate_coherence(psd_a, psd_e, csd_ae)
+    conditioned_psd_a = calculate_conditioned_psd(psd_a, coh_ae)
+    conditioned_csd_ab = calculate_conditioned_csd(csd_ab, csd_ae, csd_be, psd_e)
+
+    conditioned_tf = conditioned_csd_ab / conditioned_psd_a
+    return conditioned_tf
+
+
+def calculate_partial_coherence(csd_ab, csd_ae, csd_be, psd_e, psd_a, psd_b):
+    """Calculates the conditioned transfer function b/a between two signals of interest a and b,
+    while removing the influence of another signal, e, coherent with both signals.
+
+    Inputs:
+    -------
+    csd_ab: array
+        cross spectral density between signals a and b <a, b>
+    csd_ae: array
+        cross spectral density between signals a and e <a, e>
+    csd_be: array
+        cross spectral density between signals b and e <b, e>
+    psd_e: array
+        power spectral density of signal to be removed e <e, e>
+    psd_a: array
+        power spectral density of input signal of interest a <a, a>
+    psd_b: array
+        power spectral density of output signal of interest a <b, b>
+
+    Outputs:
+    --------
+    partial_coherence: array
+        partial coherence between signals a and b without the influence of the signal e
+    """
+    coh_ae = calculate_coherence(psd_a, psd_e, csd_ae)
+    coh_be = calculate_coherence(psd_b, psd_e, csd_be)
+
+    conditioned_psd_a = calculate_conditioned_psd(psd_a, coh_ae)
+    conditioned_psd_b = calculate_conditioned_psd(psd_b, coh_be)
+    conditioned_csd_ab = calculate_conditioned_csd(csd_ab, csd_ae, csd_be, psd_e)
+
+    partial_coherence = calculate_coherence(
+        conditioned_psd_a, conditioned_psd_b, conditioned_csd_ab
+    )
+    return partial_coherence
+
+
+def get_conditioned_psd(data_dict, psd_chan, exc_chan):
+    """
+    Gets a conditioned power spectral density from the data_dict structure.
+    The linear influence of exc_chan will be removed from the PSD of psd_chan.
+
+    Inputs:
+    -------
+    data_dict: nds2 data dictionary struture
+        dict with channel names as keys and channel info and data as values
+    psd_chan: string
+        channel name (key in data_dict) from which we want to subtract the influence of exc_chan
+    exc_chan: string
+        channel name (key in data_dict) whose linear influence we seek to remove from psd_chan's PSD
+
+    Output:
+    -------
+    conditioned_psd: array
+        power spectral density of psd_chan without the (linear) influence of exc_chan
+    """
+    if not "CSD" in data_dict[psd_chan][exc_chan].keys():
+        print("Cross spectral densities not yet calculated")
+        print(
+            f"Make sure CSDs and PSDs are calculated for data_dict[{psd_chan}] and data_dict[{exc_chan}]"
+        )
+        return data_dict
+
+    psd1 = data_dict[psd_chan]["PSD"]
+
+    # calculate the coherence if we need to
+    if not "coh" in data_dict[psd_chan][exc_chan].keys():
+        csd = data_dict[psd_chan][exc_chan]["CSD"]
+        psd2 = data_dict[exc_chan]["PSD"]
+        coh = (np.abs(csd) / (np.sqrt(psd1) * np.sqrt(psd2))) ** 2
+    else:
+        coh = data_dict[psd_chan][exc_chan]["coh"]
+
+    conditioned_psd = calculate_conditioned_psd(psd, coh)
+    return conditioned_psd
+
+
+def get_conditioned_csd(data_dict, chanA, chanB, exc_chan):
+    """
+    Calculates a conditioned cross spectral density from the data_dict structure.
+    The linear influence of exc_chan will be removed from the CSD of chanA and chanB.
+
+    Inputs:
+    -------
+    data_dict: nds2 data dictionary struture
+        dict with channel names as keys and channel info and data as values
+    chanA: string
+        channel name (key in data_dict) from whose CSD with chanB we want to subtract the influence of exc_chan
+    chanB: string
+        channel name (key in data_dict) from whose CSD with chanA we want to subtract the influence of exc_chan
+    exc_chan: string
+        channel name (key in data_dict) whose linear influence we seek to remove from psd_chan's PSD
+
+    Output:
+    -------
+    conditioned_csd: array
+        cross spectral density of chanA and chanB without the (linear) influence of exc_chan
+    """
+    if not "CSD" in data_dict[psd_chan][exc_chan].keys():
+        print("Cross spectral densities not yet calculated")
+        print(
+            f"Make sure CSDs and PSDs are calculated for data_dict[{psd_chan}] and data_dict[{exc_chan}]"
+        )
+        return data_dict
+
+    psd_e = data_dict[exc_chan]["PSD"]
+
+    csd_ab = data_dict[chanB][chanA]["CSD"]  # S_ab
+    csd_ae = data_dict[exc_chan][chanA]["CSD"]  # S_ae
+    csd_be = data_dict[exc_chan][chanB]["CSD"]  # S_be
+
+    conditioned_csd = calculate_conditioned_csd(csd_ab, csd_ae, csd_be, psd_e)
+    return conditioned_csd
+
+
+def get_conditioned_tf(data_dict, chanA, chanB, exc_chan):
+    """
+    Calculates a conditioned transfer function from the data_dict structure.
+    The linear influence of exc_chan will be removed from the TF from chanA to chanB.
+
+    Inputs:
+    -------
+    data_dict: nds2 data dictionary struture
+        dict with channel names as keys and channel info and data as values
+    chanA: string
+        channel name (key in data_dict) from whose CSD with chanB we want to subtract the influence of exc_chan
+    chanB: string
+        channel name (key in data_dict) from whose CSD with chanA we want to subtract the influence of exc_chan
+    exc_chan: string
+        channel name (key in data_dict) whose linear influence we seek to remove from psd_chan's PSD
+
+    Output:
+    -------
+    conditioned_tf: array
+        transfer function from chanA to chanB without the (linear) influence of exc_chan
+    """
+    if not "CSD" in data_dict[psd_chan][exc_chan].keys():
+        print("Cross spectral densities not yet calculated")
+        print(
+            f"Make sure CSDs and PSDs are calculated for data_dict[{psd_chan}] and data_dict[{exc_chan}]"
+        )
+        return data_dict
+
+    # Gather spectra
+    psd_a = data_dict[chanA]["PSD"]
+    psd_e = data_dict[exc_chan]["PSD"]
+
+    csd_ab = data_dict[chanB][chanA]["CSD"]  # S_ab
+    csd_ae = data_dict[exc_chan][chanA]["CSD"]  # S_ae
+    csd_be = data_dict[exc_chan][chanB]["CSD"]  # S_be
+
+    conditioned_tf = calculate_conditioned_tf(csd_ab, csd_ae, csd_be, psd_e, psd_a)
+    return conditioned_tf
+
+
+def get_partial_coherence(data_dict, chanA, chanB, exc_chan):
+    """
+    Calculates a partial coherence from the data_dict structure.
+    The linear influence of exc_chan will be removed from the CSD of chanA and chanB to reproduce the coherence estimate.
+
+    Inputs:
+    -------
+    data_dict: nds2 data dictionary struture
+        dict with channel names as keys and channel info and data as values
+    chanA: string
+        channel name (key in data_dict) from whose CSD with chanB we want to subtract the influence of exc_chan
+    chanB: string
+        channel name (key in data_dict) from whose CSD with chanA we want to subtract the influence of exc_chan
+    exc_chan: string
+        channel name (key in data_dict) whose linear influence we seek to remove from psd_chan's PSD
+
+    Output:
+    -------
+    partial_coherence: array
+        partial coherence between chanA and chanB without the (linear) influence of exc_chan
+    """
+    if not "CSD" in data_dict[psd_chan][exc_chan].keys():
+        print("Cross spectral densities not yet calculated")
+        print(
+            f"Make sure CSDs and PSDs are calculated for data_dict[{psd_chan}] and data_dict[{exc_chan}]"
+        )
+        return data_dict
+
+    # Gather spectra
+    psd_a = data_dict[chanA]["PSD"]
+    psd_b = data_dict[chanB]["PSD"]
+    psd_e = data_dict[exc_chan]["PSD"]
+
+    csd_ab = data_dict[chanB][chanA]["CSD"]  # S_ab
+    csd_ae = data_dict[exc_chan][chanA]["CSD"]  # S_ae
+    csd_be = data_dict[exc_chan][chanB]["CSD"]  # S_be
+
+    partial_coherence = calculate_partial_coherence(
+        csd_ab, csd_ae, csd_be, psd_e, psd_a, psd_b
+    )
+    return partial_coherence
