@@ -165,9 +165,12 @@ def make_interactive_svg(fig, filename='plot_svg'):
 def make_interactive_svg_multiple_subplots(fig, filename='plots_svg'):
     '''
     Produces a .svg plot file with an interactive legend for plots with multiple
-    subplots but only one legend.
+    subplots and multiple legends.
+    Lines will always be grouped in the order in which they were plotted.
     Can click lines on or off when viewed in javascript-supporting browser.
+
     Inputs:
+    -------
     fig      =  matplotlib figure object.
                 Must have one and only one subplot, a legend, and a line object.
                 Also, figure must not have been shown and closed before running
@@ -176,8 +179,12 @@ def make_interactive_svg_multiple_subplots(fig, filename='plots_svg'):
                 cannot be found by the xml parser.
     filename =  full path to save file, with no extension.
 
-    Example:
+    Output:
+    -------
+    SVG plot saved at filename + '.svg'
 
+    Usage:
+    ------
     import numpy as np
     import matplotlib.pyplot as plt
     from make_interactive_svg import *
@@ -200,6 +207,7 @@ def make_interactive_svg_multiple_subplots(fig, filename='plots_svg'):
     s2.plot(xx, -yy3, lw=3, ls='--', alpha=0.5, label='-yy3')
 
     s1.legend()
+    s2.legend()
 
     make_interactive_svg_multiple_subplots(fig, 'example_multiple_subplots_svg')
 
@@ -207,25 +215,31 @@ def make_interactive_svg_multiple_subplots(fig, filename='plots_svg'):
     ET.register_namespace("", "http://www.w3.org/2000/svg")
 
     ss = fig.get_axes()
+    legends = []
     for s in ss:
         if s.get_legend() is not None:
             leg = s.get_legend()
+            legends.append(leg)
 
     for j, s in enumerate(ss):
         containers = s.lines
         for i, c in enumerate(containers):
-             c.set_gid('lines_%d_%d' %(j, i))
+            key = f'lines_{j}_{i}'
+            c.set_gid(key)
 
     # Set ids for the legend patches
-    for i, t in enumerate(leg.get_lines()):
-        #print(i)
-        t.set_picker(5)
-        t.set_gid('leg_lines_%d' % i)
+    for k, leg in enumerate(legends):
+        for i, t in enumerate(leg.get_lines()):
+            t.set_pickradius(10)
+            key = f'leg_lines_{k}_{i}'
+            t.set_gid(key)
 
     # Set ids for the text patches
-    for i, t in enumerate(leg.get_texts()):
-        t.set_picker(5)
-        t.set_gid('leg_text_%d' % i)
+    for k, leg in enumerate(legends):
+        for i, t in enumerate(leg.get_texts()):
+            t.set_picker(10)
+            key = f'leg_text_{k}_{i}'
+            t.set_gid(key)
 
     f = BytesIO()
     plt.savefig(f, format="svg")
@@ -235,22 +249,35 @@ def make_interactive_svg_multiple_subplots(fig, filename='plots_svg'):
 
     # Add attributes to the legend line objects.
     for j, s in enumerate(ss):
+        containers = s.lines
         for i, c in enumerate(containers):
-            el = xmlid['lines_%d_%d' %(j, i)]
+            # If not all subplots have the same number of lines
+            key = f'lines_{j}_{i}'
+            try:
+                el = xmlid[key]
+            except KeyError:
+                print(f"'{key}' is not a valid key for xmlid")
+                print("skipping")
+                continue
+
             el.set('cursor', 'pointer')
             el.set('onclick', "toggle_hist(this)")
 
     # Add attributes to the legend line objects.
-    for i, t in enumerate(leg.get_lines()):
-        el = xmlid['leg_lines_%d' % i]
-        el.set('cursor', 'pointer')
-        el.set('onclick', "toggle_hist(this)")
+    for k, leg in enumerate(legends):
+        for i, t in enumerate(leg.get_lines()):
+            key = f'leg_lines_{k}_{i}'
+            el = xmlid[key]
+            el.set('cursor', 'pointer')
+            el.set('onclick', "toggle_hist(this)")
 
     # Add attributes to the text objects.
-    for i, t in enumerate(leg.get_texts()):
-        el = xmlid['leg_text_%d' % i]
-        el.set('cursor', 'pointer')
-        el.set('onclick', "toggle_hist(this)")
+    for k, leg in enumerate(legends):
+        for i, t in enumerate(leg.get_texts()):
+            key = f'leg_text_{k}_{i}'
+            el = xmlid[key]
+            el.set('cursor', 'pointer')
+            el.set('onclick', "toggle_hist(this)")
 
     # Create script defining the function `toggle_hist`.
     # We create a global variable `container` that stores the patches id
@@ -258,10 +285,17 @@ def make_interactive_svg_multiple_subplots(fig, filename='plots_svg'):
     # visibility attribute of all patches of each histogram and the opacity
     # of the marker itself.
 
-    toggle_str = ''
+    toggle_lines_str = ''
     for j, s in enumerate(ss):
-        toggle_str = "{}toggle('lines_' + {} + '_' + num, 'opacity', [1, 0]);\n        ".format(toggle_str, j)
-    #print(toggle_str)
+        toggle_lines_str = f"{toggle_lines_str}toggle('lines_' + {j} + '_' + num, 'opacity', [1, 0]);\n        "
+
+    toggle_leg_lines_str = ''
+    for k, s in enumerate(legends):
+        toggle_leg_lines_str = f"{toggle_leg_lines_str}toggle('leg_lines_' + {k} + '_' + num, 'opacity', [1, 0.2]);\n        "
+
+    toggle_leg_text_str = ''
+    for k, s in enumerate(legends):
+        toggle_leg_text_str = f"{toggle_leg_text_str}toggle('leg_text_' + {k} + '_' + num, 'opacity', [1, 0.5]);\n        "
 
     script = """
     <script type="text/ecmascript">
@@ -291,15 +325,15 @@ def make_interactive_svg_multiple_subplots(fig, filename='plots_svg'):
 
         var num = obj.id.split("_").pop();
 
-        toggle('leg_lines_' + num, 'opacity', [1, 0.2]);
-        toggle('leg_text_' + num, 'opacity', [1, 0.5]);
+        %s
+        %s
         %s
 
 
         }
     ]]>
     </script>
-    """%(toggle_str)
+    """%(toggle_leg_lines_str, toggle_leg_text_str, toggle_lines_str)
 
     # Add a transition effect
     css = tree.getchildren()[0][0]
